@@ -284,7 +284,6 @@ Device* SfdiskBackend::scanDevice(const QString& deviceNode)
         {
             if (sfdiskJsonCommand.exitCode() != 0) {
                 scanWholeDevicePartition(*d);
-
                 return d;
             }
 
@@ -298,6 +297,13 @@ Device* SfdiskBackend::scanDevice(const QString& deviceNode)
                 qDebug() << "json object created from sfdisk output is empty !\nOutput is \"" << s.data() << "\"";
             }
 
+            /* Workaround for whole device FAT partitions */
+            if(partitionTable[QLatin1String("label")].toString() == QStringLiteral("dos") &&
+               partitionTable[QLatin1String("id")].toInt() == 0) {
+                scanWholeDevicePartition(*d);
+                return d;
+            }
+
             if (!updateDevicePartitionTable(*d, partitionTable))
                 return nullptr;
 
@@ -622,6 +628,7 @@ FileSystem::Type SfdiskBackend::fileSystemNameToType(const QString& name, const
     else if (name == QStringLiteral("BitLocker")) rval = FileSystem::Type::BitLocker;
     else if (name == QStringLiteral("apfs")) rval = FileSystem::Type::Apfs;
     else if (name == QStringLiteral("minix")) rval = FileSystem::Type::Minix;
+    else if (name == QStringLiteral("bcachefs")) rval = FileSystem::Type::Bcachefs;
 
     return rval;
 }
